from PIL import Image
from tqdm import tqdm

from .commons import OUTPUT_FOLDER_NAMES, IMG_MAX_INTENSITY


def scan_tifs(parameters):
    """ scan a sequence of tif images for common values """
    lowest = IMG_MAX_INTENSITY
    highest = 0

    for tif in tqdm(parameters.tif_list):
        with tif.path.open("rb") as filehandle:
            image = Image.open(filehandle).convert(mode="I")
            mi, ma = image.getextrema()
            lowest = min(lowest, mi)
            highest = max(highest, ma)
            if (
                image.width != parameters.image_width
                or image.height != parameters.image_height
            ):
                raise ValueError("Images have different sizes")

    parameters.intensity_min = lowest
    parameters.intensity_max = highest

    return parameters


def prepare_output_dirs(parameters):
    for name in OUTPUT_FOLDER_NAMES:
        sub_path = parameters[f"{name}_dir"]
        sub_path.mkdir(exist_ok=True)
        for item in sub_path.iterdir():
            item.unlink()
    return parameters
